# Generated by Django 5.0.7 on 2024-07-26 05:25

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="FileManager",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                ("name", models.CharField(max_length=255, verbose_name="Name")),
                ("file", models.FileField(upload_to="")),
                (
                    "status",
                    models.CharField(
                        choices=[
                            ("COMPLETED", "Completed"),
                            ("ERROR", "Error"),
                            ("PENDING", "Pending"),
                            ("PROCESSING", "Processing"),
                        ],
                        default="PENDING",
                        max_length=255,
                        verbose_name="Status",
                    ),
                ),
                ("checksum", models.CharField(max_length=255, unique=True)),
                ("eof", models.BooleanField(default=False)),
                ("metadata", models.JSONField(default=dict)),
            ],
            options={
                "verbose_name": "Django Chunk File Upload",
                "verbose_name_plural": "Django Chunk File Upload",
                "db_table": "django_chunk_file_upload",
                "indexes": [
                    models.Index(fields=["checksum"], name="file_manager_checksum_idx")
                ],
            },
        ),
    ]
