{% load static i18n %}
<!DOCTYPE html>
<html lang="en">
    <head>
        <meta charset="utf-8">
        <meta name="viewport"
              content="width=device-width, initial-scale=1, shrink-to-fit=no">
        <meta name="description" content="">
        <meta name="author" content="">
        <title>Chunked Upload - Django Filemanager</title>
        <link rel="stylesheet"
              href="https://cdn.jsdelivr.net/npm/bootstrap@4.0.0/dist/css/bootstrap.min.css"
              integrity="sha384-Gn5384xqQ1aoWXA+058RXPxPg6fy4IWvTNh0E263XmFcJlSAwiGgFAW/dAiS6JXm"
              crossorigin="anonymous">
        <style>
            :root {
              --input-padding-x: .75rem;
              --input-padding-y: .75rem;
            }

            html,
            body {
              height: 100%;
            }

            body {
              display: -ms-flexbox;
              display: -webkit-box;
              display: flex;
              -ms-flex-align: center;
              -ms-flex-pack: center;
              -webkit-box-align: center;
              align-items: center;
              -webkit-box-pack: center;
              justify-content: center;
              padding-top: 40px;
              padding-bottom: 40px;
              background-color: #f5f5f5;
            }

        </style>
        {{ form.media }}
    </head>
    <body>
        <div class="container">
            <div class="card">
                <div class="card-body">
                    <h3 class="card-title">{% translate 'Drag Drop Chunked File Upload' %}</h3>
                    <form action="{% url 'django_chunk_file_upload:uploads' %}"
                          method="post"
                          id="chunk-upload-form">
                        {{ form }}
                    </form>
                </div>
            </div>
        </div>
    </body>
</html>
