#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
django-chunk-file-upload
------------

Tests for `django-chunk-file-upload` models module.
"""

from django.test import TestCase


class TestDjangoChunkFileUpload(TestCase):

    def setUp(self):
        pass

    def test_something(self):
        pass

    def tearDown(self):
        pass
